@@ -1,3 +1,6 @@
+from pkgutil import extend_path
+__path__ = extend_path(__path__, __name__)
+
 import abc
 import builtins
 import datetime
@@ -15,9 +18,9 @@ import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@cdklabs/cdk-enterprise-iac",
-    "0.0.263",
+    "0.0.411",
     __name__[0:-6],
-    "cdk-enterprise-iac@0.0.263.jsii.tgz",
+    "cdk-enterprise-iac@0.0.411.jsii.tgz",
 )
 
 __all__ = [
